@@ -184,7 +184,7 @@ def test_object_detection_predict_storage(
         ModelGroupPredict(
             model_id=cats_dogs_modelgroup.selected_model.id,
             data=storage_urls,
-            predict_options={"threshold": 0.25},
+            predict_options={"threshold": 0.25, "crops": True},
             load=False,
         )
     )
