@@ -1,3 +1,4 @@
+from indico.queries.workflow import GetWorkflow
 import pytest
 from pathlib import Path
 
@@ -5,18 +6,19 @@ from indico.client import IndicoClient
 from indico.errors import IndicoError, IndicoInputError
 from indico.filters import SubmissionFilter
 from indico.queries import (
+    GetSubmission,
     JobStatus,
+    ListSubmissions,
     ListWorkflows,
     RetrieveStorageObject,
+    SubmissionResult,
+    SubmitReview,
+    UpdateSubmission,
+    UpdateWorkflowSettings,
+    WaitForSubmissions,
     WorkflowSubmission,
     WorkflowSubmissionDetailed,
 )
-from indico.queries.submission import (
-    GetSubmission,
-    ListSubmissions,
-    SubmissionResult,
-    UpdateSubmission,
-)
 from indico.types import ModelGroup
 from indico.types.submission import Submission
 
@@ -156,3 +158,55 @@ def test_workflow_submission_mixed_args(indico, airlines_dataset):
 
     with pytest.raises(IndicoInputError):
         client.call(WorkflowSubmission(workflow_id=wf.id, files=[_file], urls=[url]))
+
+        
+def test_auto_review_enabled_in_get_workflow_response(
+    indico, org_annotate_dataset, org_annotate_model_group
+):
+    client = IndicoClient()
+    wfs = client.call(ListWorkflows(dataset_ids=[org_annotate_dataset.id]))
+    wf = max(wfs, key=lambda w: w.id)
+    
+    assert not (wf.auto_review_enabled or wf.review_enabled)
+    
+    wf = client.call(
+        UpdateWorkflowSettings(wf, enable_review=True, enable_auto_review=True)
+    )
+    assert wf.review_enabled and wf.auto_review_enabled
+
+    wf = client.call(GetWorkflow(workflow_id=wf.id))
+    assert wf.review_enabled and wf.auto_review_enabled
+
+    
+@pytest.mark.parametrize("force_complete", [None, True])
+def test_workflow_submission_auto_review(
+    indico, force_complete, org_annotate_dataset, org_annotate_model_group
+):
+    client = IndicoClient()
+    wfs = client.call(ListWorkflows(dataset_ids=[org_annotate_dataset.id]))
+    wf = max(wfs, key=lambda w: w.id)
+    wf = client.call(
+        UpdateWorkflowSettings(wf, enable_review=True, enable_auto_review=True)
+    )
+    assert wf.review_enabled and wf.auto_review_enabled
+
+    _file = str(Path(__file__).parents[1]) + "/data/org-sample.pdf"
+
+    sub_ids = client.call(WorkflowSubmission(workflow_id=wf.id, files=[_file]))
+    subs = client.call(WaitForSubmissions(sub_ids, timeout=120))
+    sub = subs[0]
+    assert sub.status == "PENDING_AUTO_REVIEW"
+    raw_result = client.call(RetrieveStorageObject(sub.result_file))
+    changes = raw_result["results"]["document"]["results"]
+    for model, preds in changes.items():
+        if isinstance(preds, dict):
+            preds["accepted"] = True
+        elif isinstance(preds, list):
+            for pred in preds:
+                pred["accepted"] = True
+    job = client.call(
+        SubmitReview(sub.id, changes=changes, force_complete=force_complete)
+    )
+    job = client.call(JobStatus(job.id))
+    submission = client.call(GetSubmission(sub.id))
+    assert submission.status == "COMPLETE" if force_complete else "PENDING_REVIEW"
